@@ -10,11 +10,8 @@ class BoletoItau(BoletoData):
         195,196,198)
     '''
 
-    # Nosso numero (sem dv) com 8 digitos
     nosso_numero = CustomProperty('nosso_numero', 8)
-    # Conta (sem dv) com 5 digitos
     conta_cedente = CustomProperty('conta_cedente', 5)
-    #  Agência (sem dv) com 4 digitos
     agencia_cedente = CustomProperty('agencia_cedente', 4)
     carteira = CustomProperty('carteira', 3)
     linha_digitavel = None
@@ -56,17 +53,4 @@ class BoletoItau(BoletoData):
                                              self.dv_agencia_conta_cedente,
                                              '000'
                                              )
-        return content
-
-    @property
-    def barcode(self):
-        digitavel = self.linha_digitavel
-        partes = [
-            digitavel[0:4],
-            digitavel[32:47],
-            digitavel[4:9],
-            digitavel[10:16],
-            digitavel[16:20],
-            digitavel[21:31],
-        ]
-        return "".join(partes)
+        return content
\ No newline at end of file
